@@ -374,6 +374,18 @@ class Ui_SignalFrame(object):
         self.gvSpectrogram.setObjectName("gvSpectrogram")
         self.horizontalLayout_4.addWidget(self.gvSpectrogram)
         self.stackedWidget.addWidget(self.pageSpectrogram)
+        self.pageLoading = QtWidgets.QWidget()
+        self.pageLoading.setObjectName("pageLoading")
+        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.pageLoading)
+        self.verticalLayout_2.setObjectName("verticalLayout_2")
+        self.labelLoadingAutoInterpretation = QtWidgets.QLabel(self.pageLoading)
+        font = QtGui.QFont()
+        font.setPointSize(12)
+        self.labelLoadingAutoInterpretation.setFont(font)
+        self.labelLoadingAutoInterpretation.setWordWrap(True)
+        self.labelLoadingAutoInterpretation.setObjectName("labelLoadingAutoInterpretation")
+        self.verticalLayout_2.addWidget(self.labelLoadingAutoInterpretation)
+        self.stackedWidget.addWidget(self.pageLoading)
         self.horizontalLayout_2.addWidget(self.stackedWidget)
         self.verticalLayout_5 = QtWidgets.QVBoxLayout()
         self.verticalLayout_5.setObjectName("verticalLayout_5")
@@ -573,6 +585,7 @@ class Ui_SignalFrame(object):
         self.labelSpectrogramMax.setText(_translate("SignalFrame", "Data<sub>max</sub>:"))
         self.btnAutoDetect.setToolTip(_translate("SignalFrame", "<html><head/><body><p>Automatically detect <span style=\" font-weight:600;\">center</span>, <span style=\" font-weight:600;\">bit length</span> and <span style=\" font-weight:600;\">tolerance</span>. You can also choose to addtionally detect the <span style=\" font-weight:600;\">noise</span> and <span style=\" font-weight:600;\">modulation</span> when clicking this button.</p></body></html>"))
         self.btnAutoDetect.setText(_translate("SignalFrame", "Autodetect parameters"))
+        self.labelLoadingAutoInterpretation.setText(_translate("SignalFrame", "<html><head/><body><p>Running automatic detecting of demodulation parameters.</p><p>You can disable this behaviour for newly loaded signals by unchecking <span style=\" font-weight:600;\">Edit</span> -&gt; <span style=\" font-weight:600;\">Auto detect signals on loading</span>.</p></body></html>"))
         self.lYScale.setText(_translate("SignalFrame", "Y-Scale"))
         self.btnShowHideStartEnd.setText(_translate("SignalFrame", "-"))
         self.lNumSelectedSamples.setToolTip(_translate("SignalFrame", "Number of currently selected samples."))
